#! /bin/sh
#-----------------------------------------------------------------------------
# /var/install/config.d/usb-update.sh - paramater update script
#
# Creation   :  2006-11-09 hbfl
# Last update:  $Id: usb-update.sh 35245 2014-03-17 19:23:30Z hbfl $
#
# Copyright (c) 2006-2014 the eisfair team, team(at)eisfair(dot)org
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#-----------------------------------------------------------------------------

# set packages name
package_name=usb

# include configlib
. /var/install/include/configlib

#------------------------------------------------------------------------------
# set default values for configuration
#------------------------------------------------------------------------------
START_USB='no'

USB_PRINTER='no'
USB_STORAGE='no'

USB_SERIAL='no'
USB_SERIAL_DRIVER=''
USB_SERIAL_OPTIONS=''

#------------------------------------------------------------------------------
# read old configuration and rename old variables
#-----------------------------------------------------------------------------
rename_old_variables()
{
    # read old values
    if [ -f /etc/config.d/${package_name} ]
    then
        /var/install/bin/backup-file --quiet ${package_name}
        . /etc/config.d/${package_name}
    fi
}

# ---------------------------------------------------------------------------
# Write config and default files
# ---------------------------------------------------------------------------
make_config_file()
{
    internal_conf_file=${1}
    {
    # -----------------------------------------------------------------------
    printgpl --conf ${package_name} "2006-10-29" "tu"
    # -----------------------------------------------------------------------

    # -----------------------------------------------------------------------
    printgroup "Basic configuration"
    # -----------------------------------------------------------------------

    printvar "START_USB"            "USE yes or no"
    echo
    printvar "USB_PRINTER"          "driver for usb-printer"
    printvar "USB_STORAGE"          "driver for usb-storage"

    # -----------------------------------------------------------------------
    printgroup "USB serial options"
    # -----------------------------------------------------------------------

    printvar "USB_SERIAL"           "Use yes or no, for driver USB to RS232 adaptors"
    printvar "USB_SERIAL_DRIVER"    "low level driver for USB serial"
    printvar "USB_SERIAL_OPTIONS"   "options USB serial driver"

    # -----------------------------------------------------------------------
    printend
    # -----------------------------------------------------------------------

    } > ${internal_conf_file}
    # Set rights
    chmod 0600 ${internal_conf_file}
    chown root ${internal_conf_file}
}
#----------------------------------------------------------------------------
# create check.d file
#----------------------------------------------------------------------------
make_check_file()
{
printgpl --check ${package_name} '2004-12-20' 'tu' >/etc/check.d/${package_name}
cat >>/etc/check.d/${package_name} <<EOF
# Variable                OPT_VARIABLE              VARIABLE_N         VALUE
START_USB                 -                         -                  YESNO

USB_PRINTER               START_USB                 -                  YESNO
USB_STORAGE               START_USB                 -                  YESNO
USB_STORAGE               START_USB                 -                  YESNO

USB_SERIAL                START_USB                 -                  YESNO
USB_SERIAL_DRIVER         USB_SERIAL                -                  NOTEMPTY
USB_SERIAL_OPTIONS        USB_SERIAL                -                  NONE
EOF

   # Set rights for check.d file
   chmod 0600 /etc/check.d/${package_name}
   chown root /etc/check.d/${package_name}

}
# ---------------------------------------------------------------------------
# main
# ---------------------------------------------------------------------------
# write default config file
make_config_file /etc/default.d/${package_name}

# update from old version
rename_old_variables

# write new config file
make_config_file /etc/config.d/${package_name}

# write check.d file
make_check_file

exit 0
# ---------------------------------------------------------------------------
# end
# ---------------------------------------------------------------------------
